@@ -343,15 +343,12 @@ if DEBUG:
 
 # cors
 if DEBUG:
-    CORS_ORIGIN_ALLOW_ALL = True
-    CORS_ORIGINS = ['localhost:8000', 'localhost:8001', 'localhost:6060', 'bs-local.com:8000']
+    CORS_ALLOW_ALL_ORIGINS = True
     CORS_ALLOW_CREDENTIALS = True
 else:
     # https://github.com/ottoyiu/django-cors-headers
-    # CORS headers defaults to 'accounts.example.com'
     _CORS_ORIGINS = env("CORS_ORIGINS", default='{0}://{1}'.format(ACCOUNT_DEFAULT_HTTP_PROTOCOL, APP_DOMAIN))
-    CORS_ORIGIN_WHITELIST = list(map(lambda x: '{}'.format(x.replace(' ', '')), _CORS_ORIGINS.split(',')))
-    #CORS_ORIGIN_WHITELIST = _CORS_ORIGINS.split(',')
+    CORS_ALLOWED_ORIGINS = list(map(lambda x: '{}'.format(x.replace(' ', '')), _CORS_ORIGINS.split(',')))
     CORS_ALLOW_CREDENTIALS = True
 
 
