@@ -4,7 +4,7 @@ import os
 from django.utils.decorators import method_decorator
 from django.views.decorators.debug import sensitive_post_parameters
 from django.views.decorators.csrf import csrf_exempt
-from django.shortcuts import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from django.core.exceptions import SuspiciousOperation
 
@@ -193,7 +193,7 @@ class LogoutView(DjangoSsoAppApiViewMixin, django_sso_app_views.LogoutView):
         request = self.request
         redirect_url = get_request_param(request, 'next')
         data = {
-            'redirect_url': redirect_url 
+            'redirect_url': redirect_url
         }
         serializer = SuccessfullLogoutResponseSerializer(instance=data,
                                                          context={'request': self.request})
