@@ -5,9 +5,9 @@ from .views import DeviceApiViewSet
 
 
 _urlpatterns = [
-    url(r'^$', DeviceApiViewSet.as_view({'get': 'list'}), name='list'),
+    url(r'^$', DeviceApiViewSet.as_view({'get': 'list'}), name='rest-list'),
     url(r'^(?P<pk>\d+)/$', DeviceApiViewSet.as_view({'get': 'retrieve', 'delete': 'destroy'}),
-        name="detail"),
+        name="rest-detail"),
 ]
 
 urlpatterns = (format_suffix_patterns(_urlpatterns), 'django_sso_app_device')
