@@ -11,6 +11,7 @@ from ... import app_settings
 from ..api_gateway.kong.functions import get_apigateway_sso_id
 from ..emails.models import EmailAddress
 from ..profiles.utils import update_profile
+from ..groups.models import Group
 
 logger = logging.getLogger('django_sso_app.core.apps.users')
 
@@ -194,6 +195,16 @@ def create_local_user_from_object(user_object, verified=False):
     return new_user
 
 
+def add_user_to_default_groups(user):
+    setattr(user, '__dssoa__user_loggin_in', True)  # do not update rev
+
+    user_groups = user.groups.values_list('name', flat=True)
+    for gn in app_settings.DEFAULT_USER_GROUPS:
+        if gn not in user_groups:
+            group, _created = Group.objects.get_or_create(name=gn)
+            user.groups.add(group)
+
+
 @transaction.atomic
 def create_local_user_from_remote_backend(remote_user_object, can_subscribe=False):
     # Creates new user only by profile object
